<?php
/**************************************************************
 *                                                            *
 *   Provides a notification to the user everytime            *
 *   your WordPress theme is updated                          *
 *                                                            *
 *   Author: Joao Araujo                                      *
 *   Profile: http://themeforest.net/user/unisphere           *
 *   Follow me: http://twitter.com/unispheredesign            *
 *                                                            *
 **************************************************************/
 
 
/**
 * Retrieving theme file path
 *
 * @return string
 */
function is_latest_theme_version()
{
    if (function_exists('simplexml_load_string')) {
        $xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
        $css_file_path = dirname(TEMPLATEPATH . DIRECTORY_SEPARATOR . 'style.css');
        $theme = wp_get_theme(basename($css_file_path), dirname($css_file_path));
        return (string)$xml->latest > (string)$theme->get('Version');
    }
    return true;
}

// Adds an update notification to the WordPress Dashboard menu
function update_notifier_menu() {
    if( is_latest_theme_version()) { // Compare current theme version with the remote XML version
        add_dashboard_page( NOTIFIER_THEME_NAME . ' Theme Updates', NOTIFIER_THEME_NAME . ' <span class="update-plugins count-1"><span class="update-count">New Updates</span></span>', 'administrator', 'theme-update-notifier', 'update_notifier');
    }
}
add_action('admin_menu', 'update_notifier_menu');

// Adds an update notification to the WordPress 3.1+ Admin Bar
function update_notifier_bar_menu() {
    if ( !is_super_admin() || !is_admin_bar_showing() ) // Don't display notification in admin bar if it's disabled or the current user isn't an administrator
        return;
    global $wp_admin_bar, $wpdb;

    if( is_latest_theme_version()) { // Compare current theme version with the remote XML version
        $wp_admin_bar->add_menu( array( 'id' => 'update_notifier', 'title' => '<span>' . NOTIFIER_THEME_NAME . ' <span id="ab-updates">New Updates</span></span>', 'href' => get_admin_url() . 'index.php?page=theme-update-notifier' ) );
    }
}
add_action( 'admin_bar_menu', 'update_notifier_bar_menu', 1000 );



// The notifier page
function update_notifier() { 
	$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
	$css_file_path = dirname(TEMPLATEPATH . '/style.css'); // Read theme current version from the style.css
    /** @var Wp_Theme $theme */
    $theme = wp_get_theme(basename($css_file_path), dirname($css_file_path));
    ?>
	<style>
		.update-nag { display: none; }
		#instructions {max-width: 670px;}
		h3.title {margin: 30px 0 0 0; padding: 30px 0 0 0; border-top: 1px solid #ddd;}
	</style>

	<div class="wrap">
	
		<div id="icon-tools" class="icon32"></div>
		<h2><?php echo NOTIFIER_THEME_NAME ?> Theme Updates</h2>
	    <div id="message" class="updated below-h2"><p><strong>There is a new version of the <?php echo NOTIFIER_THEME_NAME; ?> theme available.</strong> You have version <?php echo $theme->get('Version'); ?> installed. Update to version <?php echo $xml->latest; ?>.</p></div>

		<img style="float: left; margin: 0 20px 20px 0; border: 1px solid #ddd;" src="<?php echo get_bloginfo( 'template_url' ) . '/screenshot.jpg'; ?>" />
		
		<div id="instructions">
		    <h3>Update Download and Instructions</h3>
		    <p><strong>Please note:</strong> First make sure to create a <strong>backup</strong> of the Theme inside your WordPress installation folder <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong> . 
		    	This counts for any theme update! You want to be able to restore to a working version of your website in case something goes wrong. </p>
		    <p>To update the Theme, login to <a href="https://www.dessky.com/">Dessky</a>, head over to the <strong>Themes</strong> section and re-download the theme like you did when you bought it.</p>
		    
		    <p>Extract the zip's contents, look for the extracted theme folder, and after you have extracted new theme folder make sure that on the server via FTP you 
		    	delete or rename the old <?php echo NOTIFIER_THEME_FOLDER_NAME; ?> folder and upload the new one using FTP into the <strong>/wp-content/themes/</strong> folder. 
		    	Make sure that folder you are uploading is named '<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>' so that final path looks like this after folder is successfully uploaded <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?></strong>.
		    	</p>
		    
		</div>
	    
	    <h3 class="title">Changelog</h3>
	    <?php echo $xml->changelog; ?>

	</div>
    
<?php } 



// Get the remote XML file contents and return its data (Version and Changelog)
// Uses the cached version if available and inside the time interval defined
function get_latest_theme_version($interval) {
	$notifier_file_url = NOTIFIER_XML_FILE;	
	$db_cache_field = 'notifier-cache-'.NOTIFIER_THEME_FOLDER_NAME.'-'.NOTIFIER_THEME_LATEST_VERSION;
	$db_cache_field_last_updated = 'notifier-cache-last-updated-'.NOTIFIER_THEME_FOLDER_NAME.'-'.NOTIFIER_THEME_LATEST_VERSION;
	$last = get_option( $db_cache_field_last_updated );
	$now = time();
	// check the cache
	if ( !$last || (( $now - $last ) > $interval) ) {
		// cache doesn't exist, or is old, so refresh it
		if( function_exists('curl_init') ) { // if cURL is available, use it...
			$ch = curl_init($notifier_file_url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, 0);
			curl_setopt($ch, CURLOPT_TIMEOUT, 10);
			$cache = curl_exec($ch);
			curl_close($ch);
		} else {
			$cache = file_get_contents($notifier_file_url); // ...if not, use the common file_get_contents()
		}
		
		if ($cache) {			
			// we got good results	
			update_option( $db_cache_field, $cache );
			update_option( $db_cache_field_last_updated, time() );
		} 
		// read from the cache file
		$notifier_data = get_option( $db_cache_field );
	}
	else {
		// cache file is fresh enough, so read from it
		$notifier_data = get_option( $db_cache_field );
	}
	
	// Let's see if the $xml data was returned as we expected it to.
	// If it didn't, use the default 1.0 as the latest version so that we don't have problems when the remote server hosting the XML file is down
	if( strpos((string)$notifier_data, '<notifier>') === false ) {
		$notifier_data = '<?xml version="1.0" encoding="UTF-8"?><notifier><latest>1.0.0</latest><changelog></changelog></notifier>';
	}
	
	// Load the remote XML data into a variable and return it
	$xml = simplexml_load_string($notifier_data); 
	
	return $xml;
}

?>