<?php

	global $shop_data;

	/* Disable woocommerce default css */

	define("WOOCOMMERCE_USE_CSS", false );

	/* Support for WooCommerce */

	add_theme_support("woocommerce");

	/* Change number or products per row */

	add_filter('loop_shop_columns', 'loop_columns');
	if (!function_exists('loop_columns')) {
		function loop_columns() {
			return 3;
		}
	}

	/* Remove the Short description content area */

	function remove_short_description() {
		remove_meta_box( 'postexcerpt', 'product', 'normal');
	}

	add_action('add_meta_boxes', 'remove_short_description', 999);

	add_filter('loop_shop_columns', 'loop_columns', 999);

	/* Change the number of Related Products */

	function woocommerce_output_related_products() {
		woocommerce_related_products( array(
			'posts_per_page' => 4,
			'columns'        => 4,
			'orderby'        => 'rand',
			'order'          => 'desc',
		) );
	}

	/* Change number of Upsell Products */

	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 15 );
	 
	if ( ! function_exists( 'woocommerce_output_upsells' ) ) {
		function woocommerce_output_upsells() {
		    woocommerce_upsell_display( 4,4 );
		}
	}

	/* WPML */

	function icl_post_languages() {
	  $languages = icl_get_languages('skip_missing=1');
	  if(1 < count($languages)){
	    echo __('This post is also available in:', "nanoshop");
	    foreach($languages as $l){
	      if(!$l['active']) $langs[] = '<a href="'.$l['url'].'">'.$l['translated_name'].'</a>';
	    }
	    echo join(', ', $langs);
	  }
	}

	/* Login, Register / My Account */

	function woo_user() {
		echo '<div class="woo-user">';
		if ( is_user_logged_in() ): ?>
            <a href="<?php echo get_permalink( get_option('woocommerce_myaccount_page_id') ); ?>" title="<?php _e('My account','nanoshop'); ?>">
                <?php _e("My account", "nanoshop"); ?>
            </a>
		<?php else: ?>
            <a href="<?php echo get_permalink( get_option('woocommerce_myaccount_page_id') ); ?>" title="<?php _e('Login / Register','nanoshop'); ?>">
                <?php _e("Login / Register", "nanoshop"); ?>
            </a>
        <?php endif;
        echo '</div>';
	}

	/* Mini cart */

	function woo_mini_cart() {
		global $woocommerce;
        echo '<div class="woo-cart">';
        echo '<a class="cart-contents" href="';
		echo esc_url( wc_get_cart_url() );
		echo '" title="';
		_e('View your shopping cart', 'nanoshop');
		echo '">';
		echo wc_price($woocommerce->cart->subtotal);
		echo '</a>';
		woocommerce_mini_cart();
        echo '</div>';
	}

    /* Register Widget Area for Filter */

    register_sidebar(array(
        'name' => __('Filter', 'nanoshop'),
        'id' => 'filter-widget-area',
        'description' => __('Filter widget area', 'nanoshop'),
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 style="display: none" class="widget-title">',
        'after_title' => '</h3>',
    ));

    /* Products Per Page */

    add_filter( 'loop_shop_per_page', create_function( '$cols', 'return ' . $shop_data['shop_per_page'] . ';' ), 20 );

    /* Remove Breadcrumbs */

	remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20, 0);

	/* Load PrettyPhoto on Non-WooCommerce Pages */

    add_action( 'wp_enqueue_scripts', 'lightbox' );
        function lightbox() {
        global $woocommerce;
        $suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
        {
        wp_enqueue_script( 'prettyPhoto', $woocommerce->plugin_url() . '/assets/js/prettyPhoto/jquery.prettyPhoto' . $suffix . '.js', array( 'jquery' ), $woocommerce->version, true );
        wp_enqueue_script( 'prettyPhoto-init', $woocommerce->plugin_url() . '/assets/js/prettyPhoto/jquery.prettyPhoto.init' . $suffix . '.js', array( 'jquery' ), $woocommerce->version, true );
        wp_enqueue_style( 'woocommerce_prettyPhoto_css', $woocommerce->plugin_url() . '/assets/css/prettyPhoto.css' );
        }
    }

    /* Order Status Bar */

    function order_status( $status ) {
    	global $woocommerce;
		$myaccount_url = get_permalink(get_option( 'woocommerce_myaccount_page_id' ));
		$cart_url = wc_get_cart_url();
		$checkout_url = wc_get_checkout_url();
		$payment_page = get_permalink( wc_get_page_id( 'order-pay' ) );
		?>
			<ul class="order-status">
				<li class="first"><a <?php if( $status == "myaccout" ) { echo 'class="current"'; } ?> href="<?php echo $myaccount_url; ?>"><?php echo _e("Sign in", "nanoshop"); ?></a></li>
				<li><a <?php if( $status == "cart" ) { echo 'class="current"'; } ?> href="<?php echo $cart_url; ?>"><?php echo _e("Cart", "nanoshop"); ?></a></li>
				<li><a <?php if( $status == "checkout" ) { echo 'class="current"'; } ?> href="<?php echo $checkout_url; ?>"><?php echo _e("Checkout", "nanoshop"); ?></a></li>
				<li class="last"><a <?php if( $status == "thankyou" ) { echo 'class="current"'; } ?> href="<?php echo $payment_page; ?>"><?php echo _e("Order Complete", "nanoshop"); ?></a></li>
			</ul>
		<?php
    }

    /* My Account Sidebar */

    function myaccount_sidebar($page) { ?>

			<div class="span3 sidebar">

				<h3><?php _e("My Account", "nanoshop"); ?></h3>
				
				<ul class="myaccount-menu">
					<li class="widget-container widget_nav_menu">
						<div class="menu-main-menu-container">
							<ul class="menu">
								<li class="menu-item<?php if($page == "wishlist"){ echo " current-menu-item page_item current_page_item current_page_parent"; } ?>"><a href="<?php echo get_permalink( get_option( 'yith_wcwl_wishlist_page_id' ) ); ?>"><?php _e("My Wishlist", "nanoshop"); ?></a></li>
								<?php do_action( 'woocommerce_account_navigation' ); ?>
							</ul>
						</div>				
					</li>
				</ul>

			</div>
		<?php
    }

	/* Check if WishList and Copare plugins are active */

	function check_yith_woocommerce_wishlist() {
		if ( in_array( 'yith-woocommerce-wishlist/init.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ): ?>
			<div class="dessky-wishlist">
				<?php echo do_shortcode("[yith_wcwl_add_to_wishlist]"); ?> <span><?php _e("Wishlist", "nanoshop"); ?></span>
			</div>
		<?php endif; 
	}

	function check_yith_woocommerce_compare() {
		if ( in_array( 'yith-woocommerce-compare/init.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ): ?>
			<div class="dessky-compare">
				<?php echo do_shortcode("[yith_compare_button]"); ?> <span><?php _e("Compare", "nanoshop"); ?></span>
			</div>
		<?php endif; 
	}
	
/**
 * Suppress certain WooCommerce admin notices
 */
function suppress_woocommerce_nags() {
	if ( class_exists( 'WC_Admin_Notices' ) ) {
		// Remove the "you have outdated template files" nag
		WC_Admin_Notices::remove_notice( 'template_files' );
		
		// Remove the "install pages" nag
		WC_Admin_Notices::remove_notice( 'install' );
	}
}

add_action( 'wp_loaded', 'suppress_woocommerce_nags', 99 );

/**
 * Hide the "install the WooThemes Updater" nag
 */
remove_action( 'admin_notices', 'woothemes_updater_notice' );

?>